"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HashTable = void 0;
class HashNode {
    key;
    value;
    next;
    constructor(key, value) {
        this.key = key;
        this.value = value;
        this.next = null;
    }
}
class HashTable {
    table;
    count;
    capacity;
    constructor(capacity = 16) {
        this.table = new Array(capacity).fill(null);
        this.count = 0;
        this.capacity = capacity;
    }
    hash(key) {
        let stringKey;
        if (key === null || key === undefined) {
            stringKey = 'null';
        }
        else if (typeof key === 'object') {
            if (key instanceof Date) {
                stringKey = key.getTime().toString();
            }
            else if (key instanceof RegExp) {
                stringKey = key.toString();
            }
            stringKey = JSON.stringify(key);
        }
        else if (typeof key === 'symbol') {
            stringKey = key.toString();
        }
        else if (typeof key === 'function') {
            stringKey = key.toString();
        }
        else {
            stringKey = String(key);
        }
        let hash = 0;
        // DJB2 hash algorithm
        for (let i = 0; i < stringKey.length; i++) {
            hash = ((hash << 5) + hash) + stringKey.charCodeAt(i);
            hash = hash >>> 0; // Convert to 32-bit unsigned integer
        }
        return hash % this.capacity;
    }
    insert(key, value) {
        const index = this.hash(key);
        const newNode = new HashNode(key, value);
        if (!this.table[index]) {
            this.table[index] = newNode;
            this.count++;
            return;
        }
        let current = this.table[index];
        while (current) {
            if (this.keysEqual(current.key, key)) {
                current.value = value;
                return;
            }
            if (!current.next) {
                current.next = newNode;
                this.count++;
                return;
            }
            current = current.next;
        }
    }
    get(key) {
        const index = this.hash(key);
        let current = this.table[index];
        while (current) {
            if (this.keysEqual(current.key, key)) {
                return current.value;
            }
            current = current.next;
        }
        return undefined;
    }
    remove(key) {
        const index = this.hash(key);
        let current = this.table[index];
        let prev = null;
        while (current) {
            if (this.keysEqual(current.key, key)) {
                if (prev) {
                    prev.next = current.next;
                }
                else {
                    this.table[index] = current.next;
                }
                this.count--;
                return true;
            }
            prev = current;
            current = current.next;
        }
        return false;
    }
    keysEqual(key1, key2) {
        if (key1 === key2)
            return true;
        if (key1 == null || key2 == null)
            return false;
        if (typeof key1 !== 'object' && typeof key2 !== 'object') {
            return key1 === key2;
        }
        if (key1 instanceof Date && key2 instanceof Date) {
            return key1.getTime() === key2.getTime();
        }
        if (key1 instanceof RegExp && key2 instanceof RegExp) {
            return key1.toString() === key2.toString();
        }
        if (Array.isArray(key1) && Array.isArray(key2)) {
            return key1.length === key2.length &&
                key1.every((val, idx) => this.keysEqual(val, key2[idx]));
        }
        if (typeof key1 === 'object' && typeof key2 === 'object') {
            const keys1 = Object.keys(key1);
            const keys2 = Object.keys(key2);
            return keys1.length === keys2.length &&
                keys1.every(k => k in key2 && this.keysEqual(key1[k], key2[k]));
        }
        return false;
    }
    size() {
        return this.count;
    }
    empty() {
        return this.count === 0;
    }
    clear() {
        this.table = new Array(this.capacity).fill(null);
        this.count = 0;
    }
}
exports.HashTable = HashTable;
//# sourceMappingURL=hash-table.js.map