"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PriorityQueue = void 0;
class PriorityQueue {
    items;
    constructor() {
        this.items = [];
    }
    /**
     * Adds an element with a priority to the queue.
     * Lower priority numbers have higher precedence.
     */
    push(element, priority) {
        const item = { element, priority };
        let added = false;
        for (let i = 0; i < this.items.length; i++) {
            if (priority > this.items[i].priority) {
                this.items.splice(i, 0, item);
                added = true;
                break;
            }
        }
        if (!added)
            this.items.push(item);
    }
    /**
     * Removes and returns the highest priority element from the queue,
     * or undefined if queue is empty.
     */
    pop() {
        const item = this.items.shift();
        return item?.element;
    }
    /**
     * Returns the highest priority element without removing it,
     * or undefined if queue is empty.
     */
    front() {
        return this.items[0]?.element;
    }
    /**
     * Checks if the queue is empty. Returns true if empty, false otherwise.
     */
    empty() {
        return this.items.length === 0;
    }
    /**
     * Returns the number of elements in the queue.
     */
    size() {
        return this.items.length;
    }
    /**
     * Removes all elements from the queue.
     */
    clear() {
        this.items = [];
    }
}
exports.PriorityQueue = PriorityQueue;
//# sourceMappingURL=priority-queue.js.map