"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stack_1 = require("../lib/stack");
describe('Stack', () => {
    let stack;
    beforeEach(() => {
        stack = new stack_1.Stack();
    });
    test('should create empty stack', () => {
        expect(stack.empty()).toBe(true);
        expect(stack.size()).toBe(0);
    });
    test('should push elements to stack', () => {
        stack.push(1);
        stack.push(2);
        expect(stack.size()).toBe(2);
        expect(stack.top()).toBe(2);
    });
    test('should pop elements from stack', () => {
        stack.push(1);
        stack.push(2);
        expect(stack.pop()).toBe(2);
        expect(stack.size()).toBe(1);
        expect(stack.pop()).toBe(1);
        expect(stack.empty()).toBe(true);
    });
    test('should return undefined when popping empty stack', () => {
        expect(stack.pop()).toBeUndefined();
    });
    test('should return top element without removing it', () => {
        stack.push(1);
        stack.push(2);
        expect(stack.top()).toBe(2);
        expect(stack.size()).toBe(2);
    });
    test('should return undefined when checking top of empty stack', () => {
        expect(stack.top()).toBeUndefined();
    });
    test('should clear all elements from stack', () => {
        stack.push(1);
        stack.push(2);
        stack.push(3);
        stack.clear();
        expect(stack.empty()).toBe(true);
        expect(stack.size()).toBe(0);
    });
    test('should correctly report size', () => {
        expect(stack.size()).toBe(0);
        stack.push(1);
        expect(stack.size()).toBe(1);
        stack.push(2);
        expect(stack.size()).toBe(2);
        stack.pop();
        expect(stack.size()).toBe(1);
    });
});
//# sourceMappingURL=stack.test.js.map